package com.jz.dmp.modules.service.sys.impl;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import javax.servlet.http.HttpServletRequest;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.jz.common.bean.BaseBeanResponse;
import com.jz.common.bean.BaseResponse;
import com.jz.common.bean.PageInfoResponse;
import com.jz.common.constant.Constants;
import com.jz.common.constant.ResultCode;
import com.jz.common.persistence.BaseService;
import com.jz.dmp.modules.controller.sys.bean.DmpMemberRoleBatch;
import com.jz.dmp.modules.controller.sys.bean.DmpMemberRoleDto;
import com.jz.dmp.modules.controller.sys.bean.DmpMemberRoleRequest;
import com.jz.dmp.modules.dao.sys.DmpMemberRoleMapper;
import com.jz.dmp.modules.model.DmpMemberRole;
import com.jz.dmp.modules.service.sys.DmpMemberRoleService;

/**
 * 用户角色关系表服务的实现?
 * @author ybz
 *
 */
@Service("dmpMemberRoleService")
public class DmpMemberRoleServiceImpl extends BaseService implements DmpMemberRoleService {
	
	private static Logger logger = LoggerFactory.getLogger(DmpMemberRoleServiceImpl.class);
	
	@Autowired
	private DmpMemberRoleMapper dmpMemberRoleMapper;

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpMemberRoleService#findList(com.ycxc.vmts.controller.bean.DmpMemberRoleRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	public PageInfoResponse<DmpMemberRoleDto> findList(DmpMemberRoleRequest dmpMemberRoleRequest, HttpServletRequest httpRequest)
			throws Exception {
		PageInfoResponse<DmpMemberRoleDto> pageInfoResponse = new PageInfoResponse<>();
		
		Map<String, Object> param = new HashMap<>();
		//主键
		if (dmpMemberRoleRequest.getUserRoleId() != null) {
			param.put("userRoleId", dmpMemberRoleRequest.getUserRoleId());
		}
		//用户ID
		if (dmpMemberRoleRequest.getUserId() != null) {
			param.put("userId", dmpMemberRoleRequest.getUserId());
		}
		//角色ID
		if (dmpMemberRoleRequest.getRoleId() != null) {
			param.put("roleId", dmpMemberRoleRequest.getRoleId());
		}
		
		PageHelper.startPage(dmpMemberRoleRequest.getPageNum(), dmpMemberRoleRequest.getPageSize());
		List<DmpMemberRoleDto> list = dmpMemberRoleMapper.findList(param);
		PageInfo<DmpMemberRoleDto> pageInfo = new PageInfo<>(list);
		
		pageInfoResponse.setCode(ResultCode.SUCCESS.val());
		pageInfoResponse.setMessage("查询成功");
		pageInfoResponse.setData(pageInfo);
		return pageInfoResponse;
	}
	

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpMemberRoleService#add(com.ycxc.vmts.entity.DmpMemberRole, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor=Exception.class)
	public BaseBeanResponse<DmpMemberRole> add(DmpMemberRole dmpMemberRole, HttpServletRequest httpRequest) throws Exception {
		BaseBeanResponse<DmpMemberRole> baseBeanResponse = new BaseBeanResponse<>();
		
		dmpMemberRoleMapper.insertSelective(dmpMemberRole);
		
		baseBeanResponse.setCode(ResultCode.SUCCESS.val());
		baseBeanResponse.setMessage("新增成功");
		baseBeanResponse.setData(dmpMemberRole);
		
		return baseBeanResponse;
	}

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpMemberRoleService#edit(com.ycxc.vmts.entity.DmpMemberRole, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor=Exception.class)
	public BaseBeanResponse<DmpMemberRole> edit(DmpMemberRole dmpMemberRole, HttpServletRequest httpRequest) throws Exception {
		BaseBeanResponse<DmpMemberRole> baseBeanResponse = new BaseBeanResponse<>();
		
		dmpMemberRoleMapper.updateByPrimaryKeySelective(dmpMemberRole);
		
		baseBeanResponse.setCode(ResultCode.SUCCESS.val());
		baseBeanResponse.setMessage("修改成功");
		baseBeanResponse.setData(dmpMemberRole);
		
		return baseBeanResponse;
	}

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpMemberRoleService#findById(com.ycxc.vmts.controller.bean.DmpMemberRoleRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	public BaseBeanResponse<DmpMemberRoleDto> findById(DmpMemberRoleRequest dmpMemberRoleRequest, HttpServletRequest httpRequest)
			throws Exception {
		BaseBeanResponse<DmpMemberRoleDto> baseBeanResponse = new BaseBeanResponse<>();
		
		DmpMemberRoleDto dmpMemberRoleDto = dmpMemberRoleMapper.findById(dmpMemberRoleRequest.getUserRoleId());
		
		baseBeanResponse.setCode(ResultCode.SUCCESS.val());
		baseBeanResponse.setMessage("查询成功");
		baseBeanResponse.setData(dmpMemberRoleDto);
		
		return baseBeanResponse;
	}

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpMemberRoleService#deleteById(com.ycxc.vmts.controller.bean.DmpMemberRoleRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor=Exception.class)
	public BaseResponse deleteById(DmpMemberRoleRequest dmpMemberRoleRequest, HttpServletRequest httpRequest)
			throws Exception {
		BaseResponse baseResponse = new BaseResponse();
		
		dmpMemberRoleMapper.deleteByPrimaryKey(dmpMemberRoleRequest.getUserRoleId());
		
		baseResponse.setCode(ResultCode.SUCCESS.val());
		baseResponse.setMessage("删除成功");
		
		return baseResponse;
	}

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpMemberRoleService#addBatch(com.ycxc.vmts.controller.bean.DmpMemberRoleVo, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor=Exception.class)
	public BaseBeanResponse<DmpMemberRoleBatch> addBatch(DmpMemberRoleBatch dmpMemberRoleBatch, HttpServletRequest httpRequest) throws Exception {
		BaseBeanResponse<DmpMemberRoleBatch> baseBeanResponse = new BaseBeanResponse<>();
		
		List<DmpMemberRole> dmpMemberRoles = dmpMemberRoleBatch.getDmpMemberRoles();
		
		if (CollectionUtils.isEmpty(dmpMemberRoles)) {
			baseBeanResponse.setCode(ResultCode.PARAMS_ERROR.val());
			baseBeanResponse.setMessage("数据不能为空！");
			return baseBeanResponse;
		}
		
		dmpMemberRoles = dmpMemberRoles.stream().map(dmpMemberRole -> {
			return dmpMemberRole;
		}).collect(Collectors.toList());
		
		dmpMemberRoleMapper.insertBatch(dmpMemberRoles);
		
		baseBeanResponse.setCode(ResultCode.SUCCESS.val());
		baseBeanResponse.setMessage("批量新增成功");
		baseBeanResponse.setData(dmpMemberRoleBatch);
		
		return baseBeanResponse;
	}
	
}
